@@ -4,30 +4,15 @@
 #'
 #' @param string A string (for example names of a data frame).
 #'  
-#' @param preprocess A string (if not \code{NULL}) that will be wrapped internally
-#' into \code{stringr::regex()}. All matches will be replaced by underscores. Underscores can later turned into another separator via \code{postprocess}.
+#' @param abbreviations character with (uppercase) abbreviations. This marks
+#'  abbreviations with an underscore behind (in front of the parsing).
+#'  useful if parsinoption 1 is needed, but some abbreviations need parsing_option 2.
+#'  
+#' @param sep_in (short for separator input) A regex supplied as a character (if not \code{NULL}), which will be wrapped internally
+#' into \code{stringr::regex()}. All matches will be replaced by underscores. Underscores can later turned into another separator via \code{sep_out}.
 #' 
-#' @param replace_special_characters A character vector (if not \code{NULL}). The entries of this argument
-#' need to be elements of \code{stringi::stri_trans_list()} (like "Latin-ASCII", which is often useful) or names of lookup tables (currently
-#' only "german" is supported). In the order of the entries the letters of the input
-#'  string will be transliterated via \code{stringi::stri_trans_general()} or replaced via the 
-#'  matches of the lookup table.
+#' @param preprocess deprecated. Pls use \code{sep_in} instead
 #' 
-#' You should use this feature with care in case of \code{case = "parsed"} and 
-#' \code{case = "none"}, since for upper case letters, which have transliterations/replacements
-#'  of length 2, the second letter will be transliterated to lowercase, for example Oe, Ae, Ss, which
-#'  might not always be what is intended.
-#' 
-#' @param postprocess String that will be used as separator. The defaults are \code{"_"} 
-#' and \code{""}, regarding the specified \code{case}.
-#' @param prefix prefix (string).
-#' @param postfix postfix (string).
-#' @param empty_fill A string. If it is supplied, then each entry that matches "" will be replaced
-#' by the supplied string to this argument.
-#' @param unique_sep A string. If not \code{NULL}, then duplicated names will get 
-#' a suffix integer
-#' in the order of their appearance. The suffix is separated by the supplied string
-#'  to this argument.
 #' @param parsing_option An integer that will determine the parsing_option.
 #' #' \itemize{
 #'  \item{1: \code{RRRStudio -> RRR_Studio}}
@@ -38,15 +23,41 @@
 #'  In this way case conversion won't apply after these characters. See examples.}
 #'  \item{any other integer <= 0: no parsing"}
 #'  }
+#' 
+#' @param transliterations A character vector (if not \code{NULL}). The entries of this argument
+#' need to be elements of \code{stringi::stri_trans_list()} (like "Latin-ASCII", which is often useful) or names of lookup tables (currently
+#' only "german" is supported). In the order of the entries the letters of the input
+#'  string will be transliterated via \code{stringi::stri_trans_general()} or replaced via the 
+#'  matches of the lookup table.
 #'  
-#' @param abbreviations character with (uppercase) abbreviations. This marks
-#'  abbreviations with an underscore behind (in front of the parsing).
-#'  useful if parsinoption 1 is needed, but some abbreviations need parsing_option 2.
+#' You should use this feature with care in case of \code{case = "parsed"} and 
+#' \code{case = "none"}, since for upper case letters, which have transliterations/replacements
+#'  of length 2, the second letter will be transliterated to lowercase, for example Oe, Ae, Ss, which
+#'  might not always be what is intended.
+#' 
+#' @param replace_special_characters deprecated. Pls use \code{transliterations} instead.
+#' 
+#' @param sep_out (short for separator output) String that will be used as separator. The defaults are \code{"_"} 
+#' and \code{""}, regarding the specified \code{case}.
+#' 
+#' @param postprocess deprecated. Pls use \code{sep_out} instead.
+#' 
+#' @param unique_sep A string. If not \code{NULL}, then duplicated names will get 
+#' a suffix integer
+#' in the order of their appearance. The suffix is separated by the supplied string
+#'  to this argument.
+#'  
+#' @param empty_fill A string. If it is supplied, then each entry that matches "" will be replaced
+#' by the supplied string to this argument.
+#'  
+#' @param prefix prefix (string).
+#' 
+#' @param postfix postfix (string).
 #' 
 #' @return A character vector according the specified parameters above.
 #'
-#' @note caseconverters are vectorised over \code{postprocess}, \code{prefix} and \code{postfix}.
-#' \code{postprocess} might follow in the future.
+#' @note caseconverters are vectorised over \code{string}, \code{sep_in}, \code{sep_out},
+#'  \code{empty_fill}, \code{prefix} and \code{postfix}.
 #' @author Malte Grosser, \email{malte.grosser@@gmail.com}
 #' @keywords utilities
 #' 
@@ -77,26 +88,31 @@ NULL
 #' @export
 
 to_snake_case <- function(string,
+                          abbreviations = NULL,
+                          sep_in = NULL,
                           preprocess = NULL,
+                          parsing_option = 1,
+                          transliterations = NULL,
                           replace_special_characters = NULL,
+                          sep_out = NULL,
                           postprocess = NULL,
-                          prefix = "",
-                          postfix = "",
                           unique_sep = NULL,
                           empty_fill = NULL,
-                          parsing_option = 1,
-                          abbreviations = NULL){
+                          prefix = "",
+                          postfix = ""){
   to_any_case(string = string,
               case = "snake",
+              sep_in = sep_in,
               preprocess = preprocess,
-              protect = "_(?![:alnum:])|(?<![:alnum:])_",
+              transliterations = transliterations,
               replace_special_characters = replace_special_characters,
+              sep_out = sep_out,
               postprocess = postprocess,
               prefix = prefix,
               postfix = postfix,
               unique_sep = unique_sep,
               empty_fill = empty_fill,
-              parsing_option = parsing_option,
+              parsing_option = parsing_option, 
               abbreviations = abbreviations)
 }
 
@@ -104,26 +120,31 @@ to_snake_case <- function(string,
 #' @export
 
 to_lower_camel_case <- function(string,
+                                abbreviations = NULL,
+                                sep_in = NULL,
                                 preprocess = NULL,
+                                parsing_option = 1,
+                                transliterations = NULL, 
                                 replace_special_characters = NULL,
+                                sep_out = NULL,
                                 postprocess = NULL,
-                                prefix = "",
-                                postfix = "",
                                 unique_sep = NULL,
                                 empty_fill = NULL,
-                                parsing_option = 1,
-                                abbreviations = NULL){
+                                prefix = "",
+                                postfix = ""){
   to_any_case(string = string,
               case = "lower_camel",
+              sep_in = sep_in,
               preprocess = preprocess,
-              protect = "_(?![:alnum:])|(?<![:alnum:])_",
+              transliterations = transliterations,
               replace_special_characters = replace_special_characters,
+              sep_out = sep_out,
               postprocess = postprocess,
               prefix = prefix,
               postfix = postfix,
               unique_sep = unique_sep,
               empty_fill = empty_fill,
-              parsing_option = parsing_option,
+              parsing_option = parsing_option, 
               abbreviations = abbreviations)
 }
 
@@ -131,26 +152,31 @@ to_lower_camel_case <- function(string,
 #' @export
 
 to_upper_camel_case <- function(string,
-                              preprocess = NULL,
-                              replace_special_characters = NULL,
-                              postprocess = NULL,
-                              prefix = "",
-                              postfix = "",
-                              unique_sep = NULL,
-                              empty_fill = NULL,
-                              parsing_option = 1,
-                              abbreviations = NULL){
+                                abbreviations = NULL,
+                                sep_in = NULL,
+                                preprocess = NULL,
+                                parsing_option = 1,
+                                transliterations = NULL,
+                                replace_special_characters = NULL,
+                                sep_out = NULL,
+                                postprocess = NULL,
+                                unique_sep = NULL,
+                                empty_fill = NULL,
+                                prefix = "",
+                                postfix = ""){
   to_any_case(string = string,
               case = "upper_camel",
+              sep_in = sep_in,
               preprocess = preprocess,
-              protect = "_(?![:alnum:])|(?<![:alnum:])_",
+              transliterations = transliterations,
               replace_special_characters = replace_special_characters,
+              sep_out = sep_out,
               postprocess = postprocess,
               prefix = prefix,
               postfix = postfix,
               unique_sep = unique_sep,
               empty_fill = empty_fill,
-              parsing_option = parsing_option,
+              parsing_option = parsing_option, 
               abbreviations = abbreviations)
 }
 
@@ -158,26 +184,31 @@ to_upper_camel_case <- function(string,
 #' @export 
 
 to_screaming_snake_case <- function(string,
+                                    abbreviations = NULL,
+                                    sep_in = NULL,
                                     preprocess = NULL,
+                                    parsing_option = 1,
+                                    transliterations = NULL,
                                     replace_special_characters = NULL,
+                                    sep_out = NULL,
                                     postprocess = NULL,
-                                    prefix = "",
-                                    postfix = "",
                                     unique_sep = NULL,
                                     empty_fill = NULL,
-                                    parsing_option = 1,
-                                    abbreviations = NULL){
+                                    prefix = "",
+                                    postfix = ""){
   to_any_case(string = string,
               case = "screaming_snake",
+              sep_in = sep_in,
               preprocess = preprocess,
-              protect = "_(?![:alnum:])|(?<![:alnum:])_",
+              transliterations = transliterations,
               replace_special_characters = replace_special_characters,
+              sep_out = sep_out,
               postprocess = postprocess,
               prefix = prefix,
               postfix = postfix,
               unique_sep = unique_sep,
               empty_fill = empty_fill,
-              parsing_option = parsing_option,
+              parsing_option = parsing_option, 
               abbreviations = abbreviations)
 }
 
@@ -185,20 +216,25 @@ to_screaming_snake_case <- function(string,
 #' @export
 
 to_parsed_case <- function(string,
+                           abbreviations = NULL,
+                           sep_in = NULL,
                            preprocess = NULL,
+                           parsing_option = 1,
+                           transliterations = NULL,
                            replace_special_characters = NULL,
+                           sep_out = NULL,
                            postprocess = NULL,
-                           prefix = "",
-                           postfix = "",
                            unique_sep = NULL,
                            empty_fill = NULL,
-                           parsing_option = 1,
-                           abbreviations = NULL){
+                           prefix = "",
+                           postfix = ""){
   to_any_case(string = string,
               case = "parsed",
+              sep_in = sep_in,
               preprocess = preprocess,
-              protect = "_(?![:alnum:])|(?<![:alnum:])_",
+              transliterations = transliterations,
               replace_special_characters = replace_special_characters,
+              sep_out = sep_out,
               postprocess = postprocess,
               prefix = prefix,
               postfix = postfix,
@@ -212,20 +248,25 @@ to_parsed_case <- function(string,
 #' @export
 
 to_mixed_case <- function(string,
+                          abbreviations = NULL,
+                          sep_in = NULL,
                           preprocess = NULL,
+                          parsing_option = 1,
+                          transliterations = NULL,
                           replace_special_characters = NULL,
+                          sep_out = NULL,
                           postprocess = NULL,
-                          prefix = "",
-                          postfix = "",
                           unique_sep = NULL,
                           empty_fill = NULL,
-                          parsing_option = 1,
-                          abbreviations = NULL){
+                          prefix = "",
+                          postfix = ""){
   to_any_case(string = string,
               case = "mixed",
+              sep_in = sep_in,
               preprocess = preprocess,
-              protect = "_(?![:alnum:])|(?<![:alnum:])_",
+              transliterations = transliterations,
               replace_special_characters = replace_special_characters,
+              sep_out = sep_out,
               postprocess = postprocess,
               prefix = prefix,
               postfix = postfix,
@@ -239,20 +280,25 @@ to_mixed_case <- function(string,
 #' @export
 
 to_lower_upper_case <- function(string,
+                                abbreviations = NULL,
+                                sep_in = NULL,
                                 preprocess = NULL,
+                                parsing_option = 1,
+                                transliterations = NULL,
                                 replace_special_characters = NULL,
+                                sep_out = NULL,
                                 postprocess = NULL,
-                                prefix = "",
-                                postfix = "",
                                 unique_sep = NULL,
                                 empty_fill = NULL,
-                                parsing_option = 1,
-                                abbreviations = NULL){
+                                prefix = "",
+                                postfix = ""){
   to_any_case(string = string,
               case = "lower_upper",
+              sep_in = sep_in,
               preprocess = preprocess,
-              protect = "_(?![:alnum:])|(?<![:alnum:])_",
+              transliterations = transliterations,
               replace_special_characters = replace_special_characters,
+              sep_out = sep_out,
               postprocess = postprocess,
               prefix = prefix,
               postfix = postfix,
@@ -266,20 +312,25 @@ to_lower_upper_case <- function(string,
 #' @export
 
 to_upper_lower_case <- function(string,
+                                abbreviations = NULL,
+                                sep_in = NULL,
                                 preprocess = NULL,
+                                parsing_option = 1,
+                                transliterations = NULL,
                                 replace_special_characters = NULL,
+                                sep_out = NULL,
                                 postprocess = NULL,
-                                prefix = "",
-                                postfix = "",
                                 unique_sep = NULL,
                                 empty_fill = NULL,
-                                parsing_option = 1,
-                                abbreviations = NULL){
+                                prefix = "",
+                                postfix = ""){
   to_any_case(string = string,
               case = "upper_lower",
+              sep_in = sep_in,
               preprocess = preprocess,
-              protect = "_(?![:alnum:])|(?<![:alnum:])_",
+              transliterations = transliterations,
               replace_special_characters = replace_special_characters,
+              sep_out = sep_out,
               postprocess = postprocess,
               prefix = prefix,
               postfix = postfix,
